@@ -27,12 +27,12 @@ del _hard_dependencies, _dependency, _missing_dependencies
 
 
 
-from spiders.bing import BingSpider
+from spiders.bing import BingSpider, BingNewsSpider
 
 
 
 
 __all__ = [
-    "BingSpider",
+    "BingSpider, BingNewsSpider",
 ]
 
